@@ -2,7 +2,7 @@
 
 # ***********************IMPORTANT NMAP LICENSE TERMS************************
 # *                                                                         *
-# * The Nmap Security Scanner is (C) 1996-2014 Insecure.Com LLC. Nmap is    *
+# * The Nmap Security Scanner is (C) 1996-2015 Insecure.Com LLC. Nmap is    *
 # * also a registered trademark of Insecure.Com LLC.  This program is free  *
 # * software; you may redistribute and/or modify it under the terms of the  *
 # * GNU General Public License as published by the Free Software            *
@@ -93,8 +93,7 @@
 # *                                                                         *
 # * Source is provided to this software because we believe users have a     *
 # * right to know exactly what a program is going to do before they run it. *
-# * This also allows you to audit the software for security holes (none     *
-# * have been found so far).                                                *
+# * This also allows you to audit the software for security holes.          *
 # *                                                                         *
 # * Source code also allows you to port Nmap to new platforms, fix bugs,    *
 # * and add new features.  You are highly encouraged to send your changes   *
@@ -115,7 +114,7 @@
 # * WITHOUT ANY WARRANTY; without even the implied warranty of              *
 # * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Nmap      *
 # * license file for more details (it's in a COPYING file included with     *
-# * Nmap, and also available from https://svn.nmap.org/nmap/COPYING         *
+# * Nmap, and also available from https://svn.nmap.org/nmap/COPYING)        *
 # *                                                                         *
 # ***************************************************************************/
 
@@ -134,12 +133,12 @@ PORTS_HEADER = [
         _('Port'), _('Protocol'), _('State'), _('Service'), _('Method')]
 EXTRAPORTS_HEADER = [_('Count'), _('State'), _('Reasons')]
 
-SERVICE_COLORS = {'open':            '#ffd5d5',
-                  'closed':          '#d5ffd5',
-                  'filtered':        '#ffffd5',
-                  'unfiltered':      '#ffd5d5',
-                  'open|filtered':   '#ffd5d5',
-                  'closed|filtered': '#d5ffd5'}
+SERVICE_COLORS = {'open':            '#ffd5d5',  # noqa
+                  'closed':          '#d5ffd5',  # noqa
+                  'filtered':        '#ffffd5',  # noqa
+                  'unfiltered':      '#ffd5d5',  # noqa
+                  'open|filtered':   '#ffd5d5',  # noqa
+                  'closed|filtered': '#d5ffd5'}  # noqa
 UNKNOWN_SERVICE_COLOR = '#d5d5d5'
 
 TRACE_HEADER = [_('TTL'), _('RTT'), _('IP'), _('Hostname')]
@@ -149,8 +148,8 @@ TRACE_TEXT = _(
 
 NO_TRACE_TEXT = _("No traceroute information available.")
 
-HOP_COLOR = {'known':   '#ffffff',
-             'unknown': '#cccccc'}
+HOP_COLOR = {'known':   '#ffffff',  # noqa
+             'unknown': '#cccccc'}  # noqa
 
 SYSTEM_ADDRESS_TEXT = "[%s] %s"
 
